# The naming scheme in non-Mandriva-based distros
%if 0%{!?mklibname:1}
%define mklibname(ds)  lib%{1}%{?2:%{2}}%{-s:-static}%{-d:-devel}
%endif
%if 0%{!?mkrel:1}
%define mkrel(c) %{1}%{?dist}
%endif

Name:       labwc
Version:    0.8.4
Release:    %mkrel 1
Summary:    A Wayland window-stacking compositor
Group:      Graphical desktop/Other

License:    GPL-2.0-only
URL:        https://github.com/labwc/labwc
Source0:    https://github.com/labwc/labwc/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires: gcc
BuildRequires: meson >= 0.59.0
BuildRequires: cmake

BuildRequires: pkgconfig(cairo)
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(libinput) >= 1.14
BuildRequires: pkgconfig(librsvg-2.0) >= 2.46
BuildRequires: pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(pangocairo)
BuildRequires: pkgconfig(pixman-1)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(scdoc)
BuildRequires: pkgconfig(wayland-protocols) >= 1.35
BuildRequires: pkgconfig(wayland-server) >= 1.19.0
BuildRequires: pkgconfig(wlroots-0.18) >= 0.18.1
BuildRequires: pkgconfig(xwayland)
BuildRequires: pkgconfig(xcb)
BuildRequires: pkgconfig(xkbcommon)
BuildRequires: pkgconfig(libsfdo-basedir) >= 0.1.3
BuildRequires: gettext

Requires:   hicolor-icon-theme
# Breaks xfce4-panel 4.20.0 and under.
Requires:   (xfce4-panel >= 4.20.1 if xfce4-panel)
Recommends:   x11-server-xwayland
Recommends:   xdg-desktop-portal-wlr
# Upstream recommendations
# https://github.com/labwc/labwc?tab=readme-ov-file#7-integration
# See integration[1] for further details.
# [1]: https://labwc.github.io/integration.html
Recommends: rofi-wayland                          %dnl # Launchers
Recommends: swayidle                              %dnl # Screen idling
Recommends: swaylock                              %dnl # Screen locker
Recommends: xdg-terminal-exec                     %dnl Automatically select the preferred terminal
Suggests:   alacritty                             %dnl # Terminal. See: https://github.com/labwc/labwc?tab=readme-ov-file#6-usage
Suggests:   bemenu fuzzel wofi                    %dnl # Launchers
Suggests:   grim, slurp                           %dnl # Screen-shooter
Suggests:   swaybg, hyprpaper                     %dnl # Background image
Suggests:   waybar, yambar, lavalauncher, sfwbar  %dnl # Panel
Suggests:   wf-recorder                           %dnl # Screen recorder
Suggests:   wlopm, kanshi, wlr-randr              %dnl # Output managers
# Downstream useful stuff which already packaged in Fedora
Suggests:   foot                                  %dnl # Terminal
Suggests:   wdisplays                             %dnl # GUI display configurator for wlroots compositors

%description
Labwc stands for Lab Wayland Compositor, where lab can mean any of the
following:

  * sense of experimentation and treading new ground
  * inspired by BunsenLabs and ArchLabs
  * your favorite pet

Labwc is a wlroots-based window-stacking compositor for wayland, inspired by
openbox.

It is light-weight and independent with a focus on simply stacking windows
well and rendering some window decorations. It takes a no-bling/frills
approach and says no to features such as icons (except window buttons),
animations, decorative gradients and any other options not required to
reasonably render common themes. It relies on clients for panels, screenshots,
wallpapers and so on to create a full desktop environment.

Labwc tries to stay in keeping with wlroots and sway in terms of general
approach and coding style.

Labwc has no reliance on any particular Desktop Environment, Desktop Shell or
session. Nor does it depend on any UI toolkits such as Qt or GTK.


%prep
%autosetup -p1


%build
%meson \
    -Dxwayland=enabled \
    %{nil}
%meson_build


%install
%meson_install
%find_lang %{name}


%files -f %{name}.lang
%license LICENSE
%doc NEWS.md
%{_bindir}/%{name}
%{_datadir}/wayland-sessions/%{name}.desktop
%{_datadir}/xdg-desktop-portal/labwc-portals.conf
%{_datadir}/icons/hicolor/*/*/%{name}*.svg
%{_docdir}/%{name}/*
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*

